==> uvoxen-0.2.2.tar.gz: uvoxen-0.2.2/docs/download.md <==
<!--
SPDX-FileCopyrightText: Peter Pentchev <roam@ringlet.net>
SPDX-License-Identifier: BSD-2-Clause
-->

# Download

These are the released versions of [uvoxen](index.md) available for download.

## [0.2.2] - 2025-10-08

### Source tarball

- [uvoxen-0.2.2.tar.gz](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.2.2.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.2.2.tar.gz.asc))

### Python wheel

- [uvoxen-0.2.2-py3-none-any.whl](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.2.2-py3-none-any.whl)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.2.2-py3-none-any.whl.asc))

## [0.2.1] - 2025-06-08

### Source tarball

- [uvoxen-0.2.1.tar.gz](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.2.1.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.2.1.tar.gz.asc))

### Python wheel

- [uvoxen-0.2.1-py3-none-any.whl](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.2.1-py3-none-any.whl)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.2.1-py3-none-any.whl.asc))

## [0.2.0] - 2025-05-23

### Source tarball

- [uvoxen-0.2.0.tar.gz](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.2.0.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.2.0.tar.gz.asc))

### Python wheel

- [uvoxen-0.2.0-py3-none-any.whl](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.2.0-py3-none-any.whl)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.2.0-py3-none-any.whl.asc))

## [0.1.1] - 2025-03-12

### Source tarball

- [uvoxen-0.1.1.tar.gz](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.1.1.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.1.1.tar.gz.asc))

### Python wheel

- [uvoxen-0.1.1-py3-none-any.whl](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.1.1-py3-none-any.whl)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.1.1-py3-none-any.whl.asc))

## [0.1.0] - 2025-03-08

### Source tarball

- [uvoxen-0.1.0.tar.gz](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.1.0.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.1.0.tar.gz.asc))

### Python wheel

- [uvoxen-0.1.0-py3-none-any.whl](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.1.0-py3-none-any.whl)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.1.0-py3-none-any.whl.asc))

[0.2.2]: https://gitlab.com/ppentchev/uvoxen/-/tags/release%2F0.2.2
[0.2.1]: https://gitlab.com/ppentchev/uvoxen/-/tags/release%2F0.2.1
[0.2.0]: https://gitlab.com/ppentchev/uvoxen/-/tags/release%2F0.2.0
[0.1.1]: https://gitlab.com/ppentchev/uvoxen/-/tags/release%2F0.1.1
[0.1.0]: https://gitlab.com/ppentchev/uvoxen/-/tags/release%2F0.1.0

==> uvoxen-0.2.3.tar.gz: uvoxen-0.2.3/docs/download.md <==
<!--
SPDX-FileCopyrightText: Peter Pentchev <roam@ringlet.net>
SPDX-License-Identifier: BSD-2-Clause
-->

# Download

These are the released versions of [uvoxen](index.md) available for download.

## [0.2.3] - 2025-10-09

### Source tarball

- [uvoxen-0.2.3.tar.gz](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.2.3.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.2.3.tar.gz.asc))

### Python wheel

- [uvoxen-0.2.3-py3-none-any.whl](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.2.3-py3-none-any.whl)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.2.3-py3-none-any.whl.asc))

## [0.2.2] - 2025-10-08

### Source tarball

- [uvoxen-0.2.2.tar.gz](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.2.2.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.2.2.tar.gz.asc))

### Python wheel

- [uvoxen-0.2.2-py3-none-any.whl](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.2.2-py3-none-any.whl)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.2.2-py3-none-any.whl.asc))

## [0.2.1] - 2025-06-08

### Source tarball

- [uvoxen-0.2.1.tar.gz](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.2.1.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.2.1.tar.gz.asc))

### Python wheel

- [uvoxen-0.2.1-py3-none-any.whl](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.2.1-py3-none-any.whl)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.2.1-py3-none-any.whl.asc))

## [0.2.0] - 2025-05-23

### Source tarball

- [uvoxen-0.2.0.tar.gz](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.2.0.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.2.0.tar.gz.asc))

### Python wheel

- [uvoxen-0.2.0-py3-none-any.whl](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.2.0-py3-none-any.whl)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.2.0-py3-none-any.whl.asc))

## [0.1.1] - 2025-03-12

### Source tarball

- [uvoxen-0.1.1.tar.gz](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.1.1.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.1.1.tar.gz.asc))

### Python wheel

- [uvoxen-0.1.1-py3-none-any.whl](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.1.1-py3-none-any.whl)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.1.1-py3-none-any.whl.asc))

## [0.1.0] - 2025-03-08

### Source tarball

- [uvoxen-0.1.0.tar.gz](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.1.0.tar.gz)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.1.0.tar.gz.asc))

### Python wheel

- [uvoxen-0.1.0-py3-none-any.whl](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.1.0-py3-none-any.whl)
  (with [a PGP signature](https://devel.ringlet.net/files/devel/uvoxen/uvoxen-0.1.0-py3-none-any.whl.asc))

[0.2.3]: https://gitlab.com/ppentchev/uvoxen/-/tags/release%2F0.2.3
[0.2.2]: https://gitlab.com/ppentchev/uvoxen/-/tags/release%2F0.2.2
[0.2.1]: https://gitlab.com/ppentchev/uvoxen/-/tags/release%2F0.2.1
[0.2.0]: https://gitlab.com/ppentchev/uvoxen/-/tags/release%2F0.2.0
[0.1.1]: https://gitlab.com/ppentchev/uvoxen/-/tags/release%2F0.1.1
[0.1.0]: https://gitlab.com/ppentchev/uvoxen/-/tags/release%2F0.1.0
